@@ -17,19 +17,17 @@ _ = Config._
 class PlayerNotify:
     def __init__(self, player):
         self.player = player
-        self.notify = Notify.Notification.new(
-                '',
-                '',
-                'kwplayer'
-                )
+        self.notify = Notify.Notification.new( '', '', 'kwplayer')
 
     def refresh(self):
+        if not self.player.app.conf['use-notify']:
+            return
+
         notify = self.notify
         song = self.player.curr_song
 
-        print('PlayerNotify.refresh')
         notify.clear_hints()
-        notify.set_timeout(4000)
+        #notify.set_timeout(4000)
 
         if len(song['artist']) > 0:
             artist = Widgets.short_tooltip(song['artist'], 20)
@@ -52,30 +50,58 @@ class PlayerNotify:
         #        self.player.artist_pic.get_pixbuf())
 
         notify.clear_actions()
-        notify.add_action(
-                'media-skip-backward',
-                _('Previous'),
-                self.on_prev_action_activated,
-                None)
 
-        if self.player.is_playing():
+        try:
             notify.add_action(
-                    'media-playback-pause',
-                    _('Pause'),
-                    self.on_playpause_action_activated,
+                    'media-skip-backward',
+                    _('Previous'),
+                    self.on_prev_action_activated,
                     None)
-        else:
+            if self.player.is_playing():
+                notify.add_action(
+                        'media-playback-pause',
+                        _('Pause'),
+                        self.on_playpause_action_activated,
+                        None)
+            else:
+                notify.add_action(
+                        'media-playback-start',
+                        _('Play'),
+                        self.on_playpause_action_activated,
+                        None)
             notify.add_action(
-                    'media-playback-play',
-                    _('Play'),
-                    self.on_playpause_action_activated,
+                    'media-skip-forward',
+                    _('Next'),
+                    self.on_next_action_activated,
+                    None)
+        except Exception:
+            notify.add_action(
+                    'media-skip-backward',
+                    _('Previous'),
+                    self.on_prev_action_activated,
+                    None,
+                    None)
+            if self.player.is_playing():
+                notify.add_action(
+                        'media-playback-pause',
+                        _('Pause'),
+                        self.on_playpause_action_activated,
+                        None,
+                        None)
+            else:
+                notify.add_action(
+                        'media-playback-start',
+                        _('Play'),
+                        self.on_playpause_action_activated,
+                        None,
+                        None)
+            notify.add_action(
+                    'media-skip-forward',
+                    _('Next'),
+                    self.on_next_action_activated,
+                    None,
                     None)
 
-        notify.add_action(
-                'media-skip-forward',
-                _('Next'),
-                self.on_next_action_activated,
-                None)
         notify.set_hint('action-icons',
                 GLib.Variant.new_boolean(True))
 
@@ -83,8 +109,8 @@ class PlayerNotify:
         # and the whole notification content will be presented
         # from rhythmbox/plugins/rb-notification-plugin.c
         notify.set_category('x-gnome.music')
-        notify.set_hint('desktop-entry',
-                GLib.Variant.new_string('kwplayer'))
+        #notify.set_hint('desktop-entry',
+        #        GLib.Variant.new_string('kwplayer'))
 
         # show on lock screen
         hint = 'resident'
